@@ -11,6 +11,8 @@
 #include "cache.h"
 #include "molome.h"
 
+//#include <meventfeed.h>
+
 #include <qplatformdefs.h>
 
 class EventDisabler : public QObject
@@ -71,9 +73,12 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QmlApplicationViewer viewer;
 #if defined(Q_WS_MAEMO_5) || defined(Q_WS_MAEMO_6)
     viewer.addImportPath(QString("/opt/qtm12/imports"));
+    viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
     viewer.engine()->addPluginPath(QString("/opt/qtm12/plugins"));
 #endif
 
+    QCoreApplication::addLibraryPath(QString("/opt/nelisquare/plugins"));
+
     viewer.setAttribute(Qt::WA_OpaquePaintEvent);
     viewer.setAttribute(Qt::WA_NoSystemBackground);
     viewer.viewport()->setAttribute(Qt::WA_OpaquePaintEvent);
@@ -133,5 +138,20 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     splash.finish(&viewer);
 #endif
 
+    molome->updateinfo();
+
+    /*QDesktopServices::setUrlHandler("nelisquare",windowHelper,"showNelisquare");
+
+    MEventFeed::instance()->addItem(QString("icon name"),
+       QString("title text"),
+       QString("body text"),
+       QStringList(), //ImageList
+       QDateTime::currentDateTime(),
+       QString("footer text"),
+       false,
+       QUrl("nelisquare://checkin/123"),
+       QString("nelisquare"),
+       QString("Nelisquare"));*/
+
     return app.exec();
 }
